@@ -78,7 +78,7 @@ class APIFoqus:
     def apiget(self, post_fonction, customer_name, customer_type, project, url):
         if post_fonction == 'get_similars':
 
-            response = requests.post(url=TRAIN_CALL_ADDRESS + "/similars/" + post_fonction,
+            response = requests.post(url=PREDICT_CALL_ADDRESS + "/similars/" + post_fonction,
                                         json={"customer_name": customer_name,
                                               "customer_type": customer_type,
                                               "project_name": project,
@@ -86,7 +86,7 @@ class APIFoqus:
                                         headers=headers)
             return response.text
         elif post_fonction == 'get_category':
-            response = requests.post(url=TRAIN_CALL_ADDRESS + "/predict/" + post_fonction,
+            response = requests.post(url=PREDICT_CALL_ADDRESS + "/predict/" + post_fonction,
                                          json={"customer_name": customer_name,
                                                "customer_type": customer_type,
                                                "project_name": project,
@@ -94,7 +94,7 @@ class APIFoqus:
                                          headers=headers)
             return response.text
         elif post_fonction == 'predict_customer':
-            response = requests.post(url=TRAIN_CALL_ADDRESS + "/predict/" + post_fonction,
+            response = requests.post(url=PREDICT_CALL_ADDRESS + "/predict/" + post_fonction,
                                          json={"customer_name": customer_name,
                                                "customer_type": customer_type,
                                                "customer_universe": project,
